package com.hw.wms.service;

import java.util.List;
import com.hw.wms.domain.WmsProductOutstock;

/**
 * 成品出库记录Service接口
 * 
 * @author xs
 * @date 2023-12-20
 */
public interface IWmsProductOutstockService 
{
    /**
     * 查询成品出库记录
     * 
     * @param productOutstockId 成品出库记录主键
     * @return 成品出库记录
     */
    public WmsProductOutstock selectWmsProductOutstockByProductOutstockId(Long productOutstockId);

    /**
     * 查询成品出库记录列表
     * 
     * @param wmsProductOutstock 成品出库记录
     * @return 成品出库记录集合
     */
    public List<WmsProductOutstock> selectWmsProductOutstockList(WmsProductOutstock wmsProductOutstock);

    /**
     * 新增成品出库记录
     * 
     * @param wmsProductOutstock 成品出库记录
     * @return 结果
     */
    public int insertWmsProductOutstock(WmsProductOutstock wmsProductOutstock);

    /**
     * 修改成品出库记录
     * 
     * @param wmsProductOutstock 成品出库记录
     * @return 结果
     */
    public int updateWmsProductOutstock(WmsProductOutstock wmsProductOutstock);

    /**
     * 批量删除成品出库记录
     * 
     * @param productOutstockIds 需要删除的成品出库记录主键集合
     * @return 结果
     */
    public int deleteWmsProductOutstockByProductOutstockIds(Long[] productOutstockIds);

    /**
     * 删除成品出库记录信息
     * 
     * @param productOutstockId 成品出库记录主键
     * @return 结果
     */
    public int deleteWmsProductOutstockByProductOutstockId(Long productOutstockId);
}
